@@ -13,7 +13,7 @@ from decimal import Decimal
 from math import ceil
 from PyPDF3 import PdfFileReader
 from pdfplumber.page import Page
-#from pdfminer import settings
+from pdfminer import settings
 from pdfplumber import PDF
 from pdfminer.layout import LAParams
 from pdfminer.pdfinterp import PDFResourceManager
@@ -21,7 +21,7 @@ from pdfminer.pdfdocument import PDFDocument
 from pdfminer.pdfparser import PDFParser
 from pdfplumber.utils import DEFAULT_X_TOLERANCE, DEFAULT_Y_TOLERANCE, cluster_objects, itemgetter, \
     line_to_edge, resolve_and_decode
-from pdfminer.pdfpage import PDFPage, dict_value, PDFObjectNotFound, LITERAL_PAGES, LITERAL_PAGE, list_value
+from pdfminer.pdfpage import PDFPage, dict_value, PDFObjectNotFound, LITERAL_PAGES, LITERAL_PAGE, list_value, log
 from pdfminer.pdfinterp import PDFPageInterpreter, PDFContentParser, PDFInterpreterError
 from pdfplumber.table import TableFinder, Table, DEFAULT_TABLE_SETTINGS, edges_to_intersections, \
     intersections_to_cells, cells_to_tables, Row
@@ -47,15 +47,15 @@ class MyPDFPage(PDFPage):
                     tree[k] = v
 
             tree_type = tree.get('Type')
-            #if tree_type is None and not settings.STRICT:  # See #64
-            #    tree_type = tree.get('type')
+            if tree_type is None and not settings.STRICT:  # See #64
+                tree_type = tree.get('type')
 
             if tree_type is LITERAL_PAGES and 'Kids' in tree:
-                #log.info('Pages: Kids=%r', tree['Kids'])
+                log.info('Pages: Kids=%r', tree['Kids'])
                 for c in list_value(tree['Kids']):
                     yield from search(c, tree)
             elif tree_type is LITERAL_PAGE:
-                #log.info('Page: %r', tree)
+                log.info('Page: %r', tree)
                 yield (objid, tree)
         pages = False
         i = 0
@@ -554,10 +554,10 @@ class MyPDFPageInterpreter(PDFPageInterpreter):
                         else:
                             logger.debug('exec: %s', name)
                             func()
-                    #else:
-                    #    if settings.STRICT:
-                    #        error_msg = 'Unknown operator: %r' % name
-                    #        raise PDFInterpreterError(error_msg)
+                    else:
+                        if settings.STRICT:
+                            error_msg = 'Unknown operator: %r' % name
+                            raise PDFInterpreterError(error_msg)
                 else:
                     self.push(obj)
         except Exception as e:
@@ -1231,4 +1231,4 @@ def char_in_bbox(char, bbox):
             (h_mid < x1) and
             (v_mid >= top) and
             (v_mid < bottom)
-    )
+    )
\ No newline at end of file
